==> presto-jdbc-0.286-sources.jar: com/facebook/presto/jdbc/internal/apache/http/ExceptionLogger.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package com.facebook.presto.jdbc.internal.apache.http;

/**
 * @since 4.4
 */
public interface ExceptionLogger {

    public static final ExceptionLogger NO_OP = new ExceptionLogger() {

        @Override
        public void log(final Exception ex) {
        }

    };

    public static final ExceptionLogger STD_ERR = new ExceptionLogger() {

        @Override
        public void log(final Exception ex) {
            ex.printStackTrace();
        }

    };

    void log(Exception ex);

}

==> presto-jdbc-0.293-sources.jar: com/facebook/presto/jdbc/internal/apache/http/ExceptionLogger.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package com.facebook.presto.jdbc.internal.apache.http;

/**
 * @since 4.4
 */
public interface ExceptionLogger {

    ExceptionLogger NO_OP = new ExceptionLogger() {

        @Override
        public void log(final Exception ex) {
            // do nothing
        }

    };

    ExceptionLogger STD_ERR = new ExceptionLogger() {

        @Override
        public void log(final Exception ex) {
            ex.printStackTrace();
        }

    };

    void log(Exception ex);

}
